@@ -119,7 +119,7 @@ use vars qw($NONPRINT $VERSION);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
 BEGIN { # vvv Dat: MakeMaker needs $VERSION in a separate line
-$VERSION = "0.12"
+$VERSION = "0.13"
 }
 
 # Dat: MIME::Words has [\x00-\x1F\x7F-\xFF]. We prepare for Unicode.
@@ -329,8 +329,8 @@ sub encode_mimewords_low {
     #die if !defined $S;
     $S=Encode::decode($opts{Charset}, $S);
     # ^^^ Dat: better do a Unicode regexp match
-  }  
-  $opts{Encoding}="Q" if !defined $opts{Encoding};
+  }
+  $opts{Encoding}=defined($opts{Encoding}) ? uc($opts{Encoding}) : "Q";
   $opts{Encoding}="Q" if $opts{Encoding} ne "B"; # Dat: improvement
   $opts{Encoding}="B" if $opts{Encoding} eq "Q" and $opts{Charset} eq "UTF-8";
   # ^^^ Dat: UTF-8 encoded MimeWords must be in base64 -- quoted-printable is
@@ -898,6 +898,18 @@ is(MIME::AltWords::encode_mimewords("Me and \xABFran\xE7ois\xBB at the beach"),
 is(MIME::AltWords::encode_mimewords("Me and \xABFran\xE7ois\xBB, down at the beach\nwith Dave <dave\@ether.net>"), "=?ISO-8859-1?Q?Me_and_=ABFran=E7ois=BB,_down_at_the_beach=0Awith?=\n =?ISO-8859-1?Q?_Dave_<dave\@ether.net>?=", "MIME::Words test case 7");
 is(MIME::AltWords::decode_mimewords(MIME::AltWords::encode_mimewords("Me and \xABFran\xE7ois\xBB, down at the beach\nwith Dave <dave\@ether.net>")), "Me and \xABFran\xE7ois\xBB, down at the beach\nwith Dave <dave\@ether.net>", "MIME::Words test case 8");
 
+my $in0 = Encode::encode("windows-1251", "\x{422}\x{435}\x{441}\x{442}\x{438}\x{440}\x{43e}\x{432}\x{430}\x{43d}\x{438}\x{435}");
+my $out0b = "=?WINDOWS-1251?B?0uXx8ujw7uLg7ejl?=";
+my $out0q = "=?WINDOWS-1251?Q?=D2=E5=F1=F2=E8=F0=EE=E2=E0=ED=E8=E5?=";
+is(MIME::AltWords::encode_mimewords($in0, Charset=>"windows-1251", Encoding=>"B"), $out0b);
+is(MIME::AltWords::encode_mimewords($in0, Charset=>"windows-1251", Encoding=>"Q"), $out0q);
+is(MIME::AltWords::encode_mimewords($in0, Charset=>"windows-1251", Encoding=>"q"), $out0q);
+is(MIME::AltWords::encode_mimeword($in0, "B", "windows-1251"), $out0b);
+is(MIME::AltWords::encode_mimeword($in0, "Q", "windows-1251"), $out0q);
+is(MIME::AltWords::encode_mimeword($in0, "q", "windows-1251"), $out0q);
+is(MIME::AltWords::encode_mimewords($in0, Charset=>"windows-1251", Encoding=>"b"), $out0b);
+is(MIME::AltWords::encode_mimeword($in0, "b", "windows-1251"), $out0b);
+
 =cut
 
 1
